=======
Windows
=======

The default output format for Windows is an :doc:`app <./app>`.

Briefcase also supports creating a :doc:`Visual Studio project <./visualstudio>`
which in turn can be used to build an app.

Both output formats support packaging as a Microsoft Software Installer (MSI) or
as a ZIP file.

.. toctree::
   :maxdepth: 1

   app
   visualstudio
